==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkBrush.java <==
// java wrapper for vtkBrush object
//

package vtk;
import vtk.*;

public class vtkBrush extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetColorF_2(double id0[]);
  public void SetColorF(double id0[])
    { SetColorF_2(id0); }

  private native void SetColorF_3(double id0,double id1,double id2);
  public void SetColorF(double id0,double id1,double id2)
    { SetColorF_3(id0,id1,id2); }

  private native void SetColorF_4(double id0,double id1,double id2,double id3);
  public void SetColorF(double id0,double id1,double id2,double id3)
    { SetColorF_4(id0,id1,id2,id3); }

  private native void SetOpacityF_5(double id0);
  public void SetOpacityF(double id0)
    { SetOpacityF_5(id0); }

  private native double GetOpacityF_6();
  public double GetOpacityF()
    { return GetOpacityF_6(); }

  private native void SetColor_7(char id0,char id1,char id2);
  public void SetColor(char id0,char id1,char id2)
    { SetColor_7(id0,id1,id2); }

  private native void SetColor_8(char id0,char id1,char id2,char id3);
  public void SetColor(char id0,char id1,char id2,char id3)
    { SetColor_8(id0,id1,id2,id3); }

  private native void SetOpacity_9(char id0);
  public void SetOpacity(char id0)
    { SetOpacity_9(id0); }

  private native int GetOpacity_10();
  public int GetOpacity()
    { return GetOpacity_10(); }

  private native void GetColorF_11(double id0[]);
  public void GetColorF(double id0[])
    { GetColorF_11(id0); }

  private native void SetTexture_12(vtkImageData id0);
  public void SetTexture(vtkImageData id0)
    { SetTexture_12(id0); }

  private native long GetTexture_13();
  public vtkImageData GetTexture() {
    long temp = GetTexture_13();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetTextureProperties_14(int id0);
  public void SetTextureProperties(int id0)
    { SetTextureProperties_14(id0); }

  private native int GetTextureProperties_15();
  public int GetTextureProperties()
    { return GetTextureProperties_15(); }

  private native void DeepCopy_16(vtkBrush id0);
  public void DeepCopy(vtkBrush id0)
    { DeepCopy_16(id0); }

  public vtkBrush() { super(); }

  public vtkBrush(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-21-aarch64.pkg.tar.xz: vtk/vtkBrush.java <==
// java wrapper for vtkBrush object
//

package vtk;
import vtk.*;

public class vtkBrush extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetColorF_2(double id0[]);
  public void SetColorF(double id0[])
    { SetColorF_2(id0); }

  private native void SetColorF_3(double id0,double id1,double id2);
  public void SetColorF(double id0,double id1,double id2)
    { SetColorF_3(id0,id1,id2); }

  private native void SetColorF_4(double id0,double id1,double id2,double id3);
  public void SetColorF(double id0,double id1,double id2,double id3)
    { SetColorF_4(id0,id1,id2,id3); }

  private native void SetOpacityF_5(double id0);
  public void SetOpacityF(double id0)
    { SetOpacityF_5(id0); }

  private native double GetOpacityF_6();
  public double GetOpacityF()
    { return GetOpacityF_6(); }

  private native void SetColor_7(char id0,char id1,char id2);
  public void SetColor(char id0,char id1,char id2)
    { SetColor_7(id0,id1,id2); }

  private native void SetColor_8(char id0,char id1,char id2,char id3);
  public void SetColor(char id0,char id1,char id2,char id3)
    { SetColor_8(id0,id1,id2,id3); }

  private native void SetOpacity_9(char id0);
  public void SetOpacity(char id0)
    { SetOpacity_9(id0); }

  private native int GetOpacity_10();
  public int GetOpacity()
    { return GetOpacity_10(); }

  private native void GetColorF_11(double id0[]);
  public void GetColorF(double id0[])
    { GetColorF_11(id0); }

  private native void SetTexture_12(vtkImageData id0);
  public void SetTexture(vtkImageData id0)
    { SetTexture_12(id0); }

  private native long GetTexture_13();
  public vtkImageData GetTexture() {
    long temp = GetTexture_13();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTextureProperties_14(int id0);
  public void SetTextureProperties(int id0)
    { SetTextureProperties_14(id0); }

  private native int GetTextureProperties_15();
  public int GetTextureProperties()
    { return GetTextureProperties_15(); }

  private native void DeepCopy_16(vtkBrush id0);
  public void DeepCopy(vtkBrush id0)
    { DeepCopy_16(id0); }

  public vtkBrush() { super(); }

  public vtkBrush(long id) { super(id); }
  public native long   VTKInit();

}
